==> ThbgmExtractor-1.6.4.tar.bz2: ThbgmExtractor-1.6.4/core/Smdn.Windows.Forms.ThbgmPlayer/Smdn.Windows.Forms.ThbgmPlayer/Player.Designer.cs <==
// 
// Author:
//       smdn <smdn@smdn.jp>
// 
// Copyright (c) 2009-2017 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

namespace Smdn.Windows.Forms.ThbgmPlayer {
  partial class Player {
    /// <summary>
    /// 必要なデザイナ変数です。
    /// </summary>
    private System.ComponentModel.IContainer components = null;

    /// <summary>
    /// 使用中のリソースをすべてクリーンアップします。
    /// </summary>
    /// <param name="disposing">マネージ リソースが破棄される場合 true、破棄されない場合は false です。</param>
    protected override void Dispose(bool disposing)
    {
      DisposeInternal(disposing);

      if (disposing && (components != null)) {
        components.Dispose();
      }

      base.Dispose(disposing);
    }

    #region Windows フォーム デザイナで生成されたコード

    /// <summary>
    /// デザイナ サポートに必要なメソッドです。このメソッドの内容を
    /// コード エディタで変更しないでください。
    /// </summary>
    private void InitializeComponent()
    {
      this.components = new System.ComponentModel.Container();
      System.ComponentModel.ComponentResourceManager resources = new System.ComponentModel.ComponentResourceManager(typeof(Player));
      this.buttonPlay = new System.Windows.Forms.Button();
      this.buttonStop = new System.Windows.Forms.Button();
      this.trackBarVolume = new System.Windows.Forms.TrackBar();
      this.checkBoxRepeat = new System.Windows.Forms.CheckBox();
      this.labelPosition = new System.Windows.Forms.Label();
      this.buttonPrev = new System.Windows.Forms.Button();
      this.buttonNext = new System.Windows.Forms.Button();
      this.panelPlayerControls = new System.Windows.Forms.Panel();
      this.checkBoxAutoScroll = new System.Windows.Forms.CheckBox();
      this.effectEditor = new Smdn.Windows.Forms.ThbgmPlayer.EffectEditor();
      this.waveFormView = new Smdn.Windows.Forms.ThbgmPlayer.WaveFormView();
      this.toolTipVolume = new System.Windows.Forms.ToolTip(this.components);
      ((System.ComponentModel.ISupportInitialize)(this.trackBarVolume)).BeginInit();
      this.panelPlayerControls.SuspendLayout();
      this.SuspendLayout();
      // 
      // buttonPlay
      // 
      resources.ApplyResources(this.buttonPlay, "buttonPlay");
      this.buttonPlay.Name = "buttonPlay";
      this.buttonPlay.UseVisualStyleBackColor = true;
      // 
      // buttonStop
      // 
      resources.ApplyResources(this.buttonStop, "buttonStop");
      this.buttonStop.Name = "buttonStop";
      this.buttonStop.UseVisualStyleBackColor = true;
      // 
      // trackBarVolume
      // 
      resources.ApplyResources(this.trackBarVolume, "trackBarVolume");
      this.trackBarVolume.Name = "trackBarVolume";
      this.trackBarVolume.TickStyle = System.Windows.Forms.TickStyle.None;
      // 
      // checkBoxRepeat
      // 
      resources.ApplyResources(this.checkBoxRepeat, "checkBoxRepeat");
      this.checkBoxRepeat.Name = "checkBoxRepeat";
      this.checkBoxRepeat.UseVisualStyleBackColor = true;
      // 
      // labelPosition
      // 
      resources.ApplyResources(this.labelPosition, "labelPosition");
      this.labelPosition.Name = "labelPosition";
      // 
      // buttonPrev
      // 
      resources.ApplyResources(this.buttonPrev, "buttonPrev");
      this.buttonPrev.Name = "buttonPrev";
      this.buttonPrev.UseVisualStyleBackColor = true;
      // 
      // buttonNext
      // 
      resources.ApplyResources(this.buttonNext, "buttonNext");
      this.buttonNext.Name = "buttonNext";
      this.buttonNext.UseVisualStyleBackColor = true;
      // 
      // panelPlayerControls
      // 
      resources.ApplyResources(this.panelPlayerControls, "panelPlayerControls");
      this.panelPlayerControls.Controls.Add(this.checkBoxAutoScroll);
      this.panelPlayerControls.Controls.Add(this.trackBarVolume);
      this.panelPlayerControls.Controls.Add(this.checkBoxRepeat);
      this.panelPlayerControls.Controls.Add(this.labelPosition);
      this.panelPlayerControls.Name = "panelPlayerControls";
      // 
      // checkBoxAutoScroll
      // 
      resources.ApplyResources(this.checkBoxAutoScroll, "checkBoxAutoScroll");
      this.checkBoxAutoScroll.Name = "checkBoxAutoScroll";
      this.checkBoxAutoScroll.UseVisualStyleBackColor = true;
      // 
      // effectEditor
      // 
      resources.ApplyResources(this.effectEditor, "effectEditor");
      this.effectEditor.Effect = null;
      this.effectEditor.Name = "effectEditor";
      this.effectEditor.TabStop = false;
      // 
      // waveFormView
      // 
      resources.ApplyResources(this.waveFormView, "waveFormView");
      this.waveFormView.BgmSourcePath = null;
      this.waveFormView.Name = "waveFormView";
      this.waveFormView.SeekBarAutoTracking = false;
      this.waveFormView.SeekBarPosition = System.TimeSpan.Parse("00:00:00");
      this.waveFormView.TabStop = false;
      this.waveFormView.Track = null;
      this.waveFormView.ZoomScale = 1;
      // 
      // Player
      // 
      resources.ApplyResources(this, "$this");
      this.AutoScaleMode = System.Windows.Forms.AutoScaleMode.Font;
      this.Controls.Add(this.panelPlayerControls);
      this.Controls.Add(this.buttonNext);
      this.Controls.Add(this.buttonPrev);
      this.Controls.Add(this.buttonStop);
      this.Controls.Add(this.buttonPlay);
      this.Controls.Add(this.effectEditor);
      this.Controls.Add(this.waveFormView);
      this.Name = "Player";
      ((System.ComponentModel.ISupportInitialize)(this.trackBarVolume)).EndInit();
      this.panelPlayerControls.ResumeLayout(false);
      this.panelPlayerControls.PerformLayout();
      this.ResumeLayout(false);

    }

    #endregion

    private Smdn.Windows.Forms.ThbgmPlayer.WaveFormView waveFormView;
    private Smdn.Windows.Forms.ThbgmPlayer.EffectEditor effectEditor;
    private System.Windows.Forms.Button buttonPlay;
    private System.Windows.Forms.Button buttonStop;
    private System.Windows.Forms.TrackBar trackBarVolume;
    private System.Windows.Forms.CheckBox checkBoxRepeat;
    private System.Windows.Forms.Label labelPosition;
    private System.Windows.Forms.Button buttonPrev;
    private System.Windows.Forms.Button buttonNext;
    private System.Windows.Forms.Panel panelPlayerControls;
    private System.Windows.Forms.ToolTip toolTipVolume;
    private System.Windows.Forms.CheckBox checkBoxAutoScroll;
  }
}

==> ThbgmExtractor-1.6.5.tar.bz2: ThbgmExtractor-1.6.5/core/Smdn.Windows.Forms.ThbgmPlayer/Smdn.Windows.Forms.ThbgmPlayer/Player.Designer.cs <==
// 
// Author:
//       smdn <smdn@smdn.jp>
// 
// Copyright (c) 2009-2019 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

namespace Smdn.Windows.Forms.ThbgmPlayer {
  partial class Player {
    /// <summary>
    /// 必要なデザイナ変数です。
    /// </summary>
    private System.ComponentModel.IContainer components = null;

    /// <summary>
    /// 使用中のリソースをすべてクリーンアップします。
    /// </summary>
    /// <param name="disposing">マネージ リソースが破棄される場合 true、破棄されない場合は false です。</param>
    protected override void Dispose(bool disposing)
    {
      DisposeInternal(disposing);

      if (disposing && (components != null)) {
        components.Dispose();
      }

      base.Dispose(disposing);
    }

    #region Windows フォーム デザイナで生成されたコード

    /// <summary>
    /// デザイナ サポートに必要なメソッドです。このメソッドの内容を
    /// コード エディタで変更しないでください。
    /// </summary>
    private void InitializeComponent()
    {
      this.components = new System.ComponentModel.Container();
      System.ComponentModel.ComponentResourceManager resources = new System.ComponentModel.ComponentResourceManager(typeof(Player));
      this.buttonPlay = new System.Windows.Forms.Button();
      this.buttonStop = new System.Windows.Forms.Button();
      this.trackBarVolume = new System.Windows.Forms.TrackBar();
      this.checkBoxRepeat = new System.Windows.Forms.CheckBox();
      this.buttonPrev = new System.Windows.Forms.Button();
      this.buttonNext = new System.Windows.Forms.Button();
      this.checkBoxAutoScroll = new System.Windows.Forms.CheckBox();
      this.toolTipVolume = new System.Windows.Forms.ToolTip(this.components);
      this.flowLayoutPanelPlayerControls = new System.Windows.Forms.FlowLayoutPanel();
      this.labelPosition = new System.Windows.Forms.Label();
      this.tableLayoutPanelMain = new System.Windows.Forms.TableLayoutPanel();
      this.panelLeft = new System.Windows.Forms.Panel();
      this.waveFormView = new Smdn.Windows.Forms.ThbgmPlayer.WaveFormView();
      this.effectEditor = new Smdn.Windows.Forms.ThbgmPlayer.EffectEditor();
      ((System.ComponentModel.ISupportInitialize)(this.trackBarVolume)).BeginInit();
      this.flowLayoutPanelPlayerControls.SuspendLayout();
      this.tableLayoutPanelMain.SuspendLayout();
      this.panelLeft.SuspendLayout();
      this.SuspendLayout();
      // 
      // buttonPlay
      // 
      resources.ApplyResources(this.buttonPlay, "buttonPlay");
      this.buttonPlay.Name = "buttonPlay";
      this.buttonPlay.UseVisualStyleBackColor = true;
      // 
      // buttonStop
      // 
      resources.ApplyResources(this.buttonStop, "buttonStop");
      this.buttonStop.Name = "buttonStop";
      this.buttonStop.UseVisualStyleBackColor = true;
      // 
      // trackBarVolume
      // 
      resources.ApplyResources(this.trackBarVolume, "trackBarVolume");
      this.trackBarVolume.Name = "trackBarVolume";
      this.trackBarVolume.TickStyle = System.Windows.Forms.TickStyle.None;
      // 
      // checkBoxRepeat
      // 
      resources.ApplyResources(this.checkBoxRepeat, "checkBoxRepeat");
      this.checkBoxRepeat.Name = "checkBoxRepeat";
      this.checkBoxRepeat.UseVisualStyleBackColor = true;
      // 
      // buttonPrev
      // 
      resources.ApplyResources(this.buttonPrev, "buttonPrev");
      this.buttonPrev.Name = "buttonPrev";
      this.buttonPrev.UseVisualStyleBackColor = true;
      // 
      // buttonNext
      // 
      resources.ApplyResources(this.buttonNext, "buttonNext");
      this.buttonNext.Name = "buttonNext";
      this.buttonNext.UseVisualStyleBackColor = true;
      // 
      // checkBoxAutoScroll
      // 
      resources.ApplyResources(this.checkBoxAutoScroll, "checkBoxAutoScroll");
      this.checkBoxAutoScroll.Name = "checkBoxAutoScroll";
      this.checkBoxAutoScroll.UseVisualStyleBackColor = true;
      // 
      // flowLayoutPanelPlayerControls
      // 
      this.flowLayoutPanelPlayerControls.Controls.Add(this.buttonStop);
      this.flowLayoutPanelPlayerControls.Controls.Add(this.buttonPlay);
      this.flowLayoutPanelPlayerControls.Controls.Add(this.buttonPrev);
      this.flowLayoutPanelPlayerControls.Controls.Add(this.buttonNext);
      this.flowLayoutPanelPlayerControls.Controls.Add(this.trackBarVolume);
      this.flowLayoutPanelPlayerControls.Controls.Add(this.checkBoxRepeat);
      this.flowLayoutPanelPlayerControls.Controls.Add(this.checkBoxAutoScroll);
      this.flowLayoutPanelPlayerControls.Controls.Add(this.labelPosition);
      resources.ApplyResources(this.flowLayoutPanelPlayerControls, "flowLayoutPanelPlayerControls");
      this.flowLayoutPanelPlayerControls.Name = "flowLayoutPanelPlayerControls";
      // 
      // labelPosition
      // 
      resources.ApplyResources(this.labelPosition, "labelPosition");
      this.labelPosition.Name = "labelPosition";
      // 
      // tableLayoutPanelMain
      // 
      resources.ApplyResources(this.tableLayoutPanelMain, "tableLayoutPanelMain");
      this.tableLayoutPanelMain.Controls.Add(this.panelLeft, 0, 0);
      this.tableLayoutPanelMain.Controls.Add(this.effectEditor, 1, 0);
      this.tableLayoutPanelMain.Name = "tableLayoutPanelMain";
      // 
      // panelLeft
      // 
      this.panelLeft.Controls.Add(this.waveFormView);
      this.panelLeft.Controls.Add(this.flowLayoutPanelPlayerControls);
      resources.ApplyResources(this.panelLeft, "panelLeft");
      this.panelLeft.Name = "panelLeft";
      // 
      // waveFormView
      // 
      resources.ApplyResources(this.waveFormView, "waveFormView");
      this.waveFormView.BgmSourcePath = null;
      this.waveFormView.DisplayWaveForm = true;
      this.waveFormView.Name = "waveFormView";
      this.waveFormView.SeekBarAutoTracking = false;
      this.waveFormView.SeekBarPosition = System.TimeSpan.Parse("00:00:00");
      this.waveFormView.TabStop = false;
      this.waveFormView.Track = null;
      this.waveFormView.ZoomScale = 1;
      // 
      // effectEditor
      // 
      resources.ApplyResources(this.effectEditor, "effectEditor");
      this.effectEditor.Effect = null;
      this.effectEditor.Name = "effectEditor";
      this.effectEditor.TabStop = false;
      // 
      // Player
      // 
      resources.ApplyResources(this, "$this");
      this.AutoScaleMode = System.Windows.Forms.AutoScaleMode.Font;
      this.Controls.Add(this.tableLayoutPanelMain);
      this.Name = "Player";
      ((System.ComponentModel.ISupportInitialize)(this.trackBarVolume)).EndInit();
      this.flowLayoutPanelPlayerControls.ResumeLayout(false);
      this.flowLayoutPanelPlayerControls.PerformLayout();
      this.tableLayoutPanelMain.ResumeLayout(false);
      this.panelLeft.ResumeLayout(false);
      this.ResumeLayout(false);

    }

    #endregion

    private Smdn.Windows.Forms.ThbgmPlayer.WaveFormView waveFormView;
    private Smdn.Windows.Forms.ThbgmPlayer.EffectEditor effectEditor;
    private System.Windows.Forms.Button buttonPlay;
    private System.Windows.Forms.Button buttonStop;
    private System.Windows.Forms.TrackBar trackBarVolume;
    private System.Windows.Forms.CheckBox checkBoxRepeat;
    private System.Windows.Forms.Button buttonPrev;
    private System.Windows.Forms.Button buttonNext;
    private System.Windows.Forms.ToolTip toolTipVolume;
    private System.Windows.Forms.CheckBox checkBoxAutoScroll;
    private System.Windows.Forms.FlowLayoutPanel flowLayoutPanelPlayerControls;
    private System.Windows.Forms.Label labelPosition;
    private System.Windows.Forms.TableLayoutPanel tableLayoutPanelMain;
    private System.Windows.Forms.Panel panelLeft;
  }
}
